svn commit: r251612 - head/sys/fs/ext2fs

Pedro F. Giffuni pfg at FreeBSD.org
Tue Jun 11 02:47:09 UTC 2013


Author: pfg
Date: Tue Jun 11 02:47:07 2013
New Revision: 251612
URL: http://svnweb.freebsd.org/changeset/base/251612

Log:
  s/file system/filesystem/g
  
  Based on r96755 from UFS.
  
  MFC after:	3 days

Modified:
  head/sys/fs/ext2fs/ext2_alloc.c
  head/sys/fs/ext2fs/ext2_balloc.c
  head/sys/fs/ext2fs/ext2_vfsops.c

Modified: head/sys/fs/ext2fs/ext2_alloc.c
==============================================================================
--- head/sys/fs/ext2fs/ext2_balloc.c	Mon Jun 10 23:09:45 2013	(r251611)
+++ head/sys/fs/ext2fs/ext2_balloc.c	Tue Jun 11 02:47:07 2013	(r251612)
@@ -50,7 +50,7 @@
 #include <fs/ext2fs/ext2_extern.h>
 #include <fs/ext2fs/ext2_mount.h>
 /*
- * Balloc defines the structure of file system storage
+ * Balloc defines the structure of filesystem storage
  * by allocating the physical blocks on a device given
  * the inode and the logical block number in a file.
  */

Modified: head/sys/fs/ext2fs/ext2_vfsops.c
==============================================================================
--- head/sys/fs/ext2fs/ext2_vfsops.c	Mon Jun 10 23:09:45 2013	(r251611)
+++ head/sys/fs/ext2fs/ext2_vfsops.c	Tue Jun 11 02:47:07 2013	(r251612)
@@ -747,7 +747,7 @@ ext2_flushfiles(struct mount *mp, int fl
 	return (error);
 }
 /*
- * Get file system statistics.
+ * Get filesystem statistics.
  */
 int
 ext2_statfs(struct mount *mp, struct statfs *sbp)
@@ -852,7 +852,7 @@ loop:
 	}
 
 	/*
-	 * Force stale file system control information to be flushed.
+	 * Force stale filesystem control information to be flushed.
 	 */
 	if (waitfor != MNT_LAZY) {
 		vn_lock(ump->um_devvp, LK_EXCLUSIVE | LK_RETRY);


More information about the svn-src-head mailing list
--- head/sys/fs/ext2fs/ext2_alloc.c	Mon Jun 10 23:09:45 2013	(r251611)
+++ head/sys/fs/ext2fs/ext2_alloc.c	Tue Jun 11 02:47:07 2013	(r251612)
@@ -63,7 +63,7 @@ static daddr_t	ext2_nodealloccg(struct i
 static daddr_t  ext2_mapsearch(struct m_ext2fs *, char *, daddr_t);
 
 /*
  * Allocate a block in the file system.
  *
  * A preference may be optionally specified. If a preference is given
  * the following hierarchy is used to allocate a block:
@@ -125,8 +125,8 @@ ext2_alloc(struct inode *ip, int32_t lbn
         }
 nospace:
 	EXT2_UNLOCK(ump);
-	ext2_fserr(fs, cred->cr_uid, "file system full");
-	uprintf("\n%s: write failed, file system is full\n", fs->e2fs_fsmnt);
+	ext2_fserr(fs, cred->cr_uid, "filesystem full");
+	uprintf("\n%s: write failed, filesystem is full\n", fs->e2fs_fsmnt);
 	return (ENOSPC);
 }
 
@@ -338,7 +338,7 @@ fail:
 }
 
 /*
  * Allocate an inode in the file system.
  * 
  */
 int
@@ -1083,7 +1083,7 @@ ext2_mapsearch(struct m_ext2fs *fs, char
 }
 
 /*
  * Fserr prints the name of a file system with an error diagnostic.
  * 
  * The form of the error message is:
  *	fs: error message
@@ -63,7 +63,7 @@ static daddr_t	ext2_nodealloccg(struct i
 
 /*
- * Allocate a block in the file system.
+ * Allocate a block in the filesystem.
  *
  * A preference may be optionally specified. If a preference is given
@@ -338,7 +338,7 @@ fail:
 
 /*
- * Allocate an inode in the file system.
+ * Allocate an inode in the filesystem.
  * 
  */
@@ -1083,7 +1083,7 @@ ext2_mapsearch(struct m_ext2fs *fs, char
 
 /*
- * Fserr prints the name of a file system with an error diagnostic.
+ * Fserr prints the name of a filesystem with an error diagnostic.
  * 
  * The form of the error message is:

Modified: head/sys/fs/ext2fs/ext2_balloc.c
==============================================================================